@@ -5,6 +5,20 @@ from south.db import db
 from south.v2 import SchemaMigration
 from django.db import models
 
+try:
+    from django.contrib.auth import get_user_model
+except ImportError:  # Django < 1.5
+    from django.contrib.auth.models import User
+else:
+    User = get_user_model()
+
+
+USER_MODEL = {
+    'orm_label': '%s.%s' % (User._meta.app_label, User._meta.object_name),
+    'model_label': '%s.%s' % (User._meta.app_label, User._meta.module_name),
+    'object_name': User.__name__,
+}
+
 
 class Migration(SchemaMigration):
 
@@ -32,8 +46,8 @@ class Migration(SchemaMigration):
             'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
             'name': ('django.db.models.fields.CharField', [], {'max_length': '50'})
         },
-        'auth.user': {
-            'Meta': {'object_name': 'User'},
+        USER_MODEL['model_label']: {
+            'Meta': {'object_name': USER_MODEL['object_name']},
             'date_joined': ('django.db.models.fields.DateTimeField', [], {'default': 'datetime.datetime.now'}),
             'email': ('django.db.models.fields.EmailField', [], {'max_length': '75', 'blank': 'True'}),
             'first_name': ('django.db.models.fields.CharField', [], {'max_length': '30', 'blank': 'True'}),
@@ -64,7 +78,7 @@ class Migration(SchemaMigration):
             'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
             'message': ('django.db.models.fields.TextField', [], {'max_length': '4000'}),
             'object_id': ('django.db.models.fields.PositiveIntegerField', [], {'null': 'True', 'blank': 'True'}),
-            'user': ('django.db.models.fields.related.ForeignKey', [], {'blank': 'True', 'related_name': "'feedback_form_submissions'", 'null': 'True', 'to': "orm['auth.User']"})
+            'user': ('django.db.models.fields.related.ForeignKey', [], {'blank': 'True', 'related_name': "'feedback_form_submissions'", 'null': 'True', 'to': u"orm['%s']" % USER_MODEL['orm_label']})
         }
     }
 
